@@ -13,8 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import logging
-from logging import Logger
+from dataclasses import asdict as dataclass_asdict
+from dataclasses import dataclass
+from dataclasses import is_dataclass
+import json
 import os
 import sys
 from typing import Any
@@ -23,6 +25,10 @@ from typing import List
 from typing import Optional
 
 from elyra.pipeline.pipeline_constants import ENV_VARIABLES
+from elyra.pipeline.pipeline_constants import KUBERNETES_POD_ANNOTATIONS
+from elyra.pipeline.pipeline_constants import KUBERNETES_SECRETS
+from elyra.pipeline.pipeline_constants import KUBERNETES_TOLERATIONS
+from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
 
 # TODO: Make pipeline version available more widely
 # as today is only available on the pipeline editor
@@ -95,6 +101,39 @@ class Operation(object):
         self._component_params = component_params or {}
         self._doc = None
 
+        self._mounted_volumes = []
+        param_volumes = component_params.get(MOUNTED_VOLUMES)
+        if (
+            param_volumes is not None
+            and isinstance(param_volumes, list)
+            and (len(param_volumes) == 0 or isinstance(param_volumes[0], VolumeMount))
+        ):
+            # The mounted_volumes property is an Elyra system property (ie, not defined in the component
+            # spec) and must be removed from the component_params dict
+            self._mounted_volumes = self._component_params.pop(MOUNTED_VOLUMES, [])
+
+        self._kubernetes_tolerations = []
+        param_tolerations = component_params.get(KUBERNETES_TOLERATIONS)
+        if (
+            param_tolerations is not None
+            and isinstance(param_tolerations, list)
+            and (len(param_tolerations) == 0 or isinstance(param_tolerations[0], KubernetesToleration))
+        ):
+            # The kubernetes_tolerations property is the Elyra system property (ie, not defined in the component
+            # spec) and must be removed from the component_params dict
+            self._kubernetes_tolerations = self._component_params.pop(KUBERNETES_TOLERATIONS, [])
+
+        self._kubernetes_pod_annotations = []
+        param_annotations = component_params.get(KUBERNETES_POD_ANNOTATIONS)
+        if (
+            param_annotations is not None
+            and isinstance(param_annotations, list)
+            and (len(param_annotations) == 0 or isinstance(param_annotations[0], KubernetesAnnotation))
+        ):
+            # The kubernetes_pod_annotations property is an Elyra system property (ie, not defined in the component
+            # spec) and must be removed from the component_params dict
+            self._kubernetes_pod_annotations = self._component_params.pop(KUBERNETES_POD_ANNOTATIONS, [])
+
         # Scrub the inputs and outputs lists
         self._component_params["inputs"] = Operation._scrub_list(component_params.get("inputs", []))
         self._component_params["outputs"] = Operation._scrub_list(component_params.get("outputs", []))
@@ -139,6 +178,18 @@ class Operation(object):
     def component_params_as_dict(self) -> Dict[str, Any]:
         return self._component_params or {}
 
+    @property
+    def mounted_volumes(self) -> List["VolumeMount"]:
+        return self._mounted_volumes
+
+    @property
+    def kubernetes_tolerations(self) -> List["KubernetesToleration"]:
+        return self._kubernetes_tolerations
+
+    @property
+    def kubernetes_pod_annotations(self) -> List["KubernetesAnnotation"]:
+        return self._kubernetes_pod_annotations
+
     @property
     def inputs(self) -> Optional[List[str]]:
         return self._component_params.get("inputs")
@@ -151,6 +202,10 @@ class Operation(object):
     def outputs(self) -> Optional[List[str]]:
         return self._component_params.get("outputs")
 
+    @property
+    def is_generic(self) -> bool:
+        return isinstance(self, GenericOperation)
+
     @outputs.setter
     def outputs(self, value: List[str]):
         self._component_params["outputs"] = value
@@ -306,6 +361,10 @@ class GenericOperation(Operation):
     def gpu(self) -> Optional[str]:
         return self._component_params.get("gpu")
 
+    @property
+    def kubernetes_secrets(self) -> List["KubernetesSecret"]:
+        return self._component_params.get(KUBERNETES_SECRETS)
+
     def __eq__(self, other: "GenericOperation") -> bool:
         if isinstance(self, other.__class__):
             return super().__eq__(other)
@@ -432,7 +491,7 @@ class KeyValueList(list):
 
     _key_value_separator: str = "="
 
-    def to_dict(self, logger: Optional[Logger] = None) -> Dict[str, str]:
+    def to_dict(self) -> Dict[str, str]:
         """
         Properties consisting of key-value pairs are stored in a list of separated
         strings, while most processing steps require a dictionary - so we must convert.
@@ -454,26 +513,29 @@ class KeyValueList(list):
 
             key = key.strip()
             if not key:
-                KeyValueList.log_message(f"Skipping inclusion of property '{kv}': no key found", logger, logging.WARN)
+                # Invalid entry; skip inclusion and continue
                 continue
+
             if isinstance(value, str):
                 value = value.strip()
             if not value:
-                KeyValueList.log_message(
-                    f"Skipping inclusion of property '{key}': no value specified", logger, logging.DEBUG
-                )
+                # Invalid entry; skip inclusion and continue
                 continue
 
             kv_dict[key] = value
         return kv_dict
 
+    @classmethod
+    def to_str(cls, key: str, value: str) -> str:
+        return f"{key}{cls._key_value_separator}{value}"
+
     @classmethod
     def from_dict(cls, kv_dict: Dict) -> "KeyValueList":
         """
         Convert a set of key-value pairs stored in a dictionary to
         a KeyValueList of strings with the defined separator.
         """
-        str_list = [f"{key}{cls._key_value_separator}{value}" for key, value in kv_dict.items()]
+        str_list = [KeyValueList.to_str(key, value) for key, value in kv_dict.items()]
         return KeyValueList(str_list)
 
     @classmethod
@@ -487,12 +549,61 @@ class KeyValueList(list):
 
         return KeyValueList.from_dict({**secondary_dict, **primary_dict})
 
-    @staticmethod
-    def log_message(msg: str, logger: Optional[Logger] = None, level: Optional[int] = logging.DEBUG):
+    @classmethod
+    def difference(cls, minuend: "KeyValueList", subtrahend: "KeyValueList") -> "KeyValueList":
         """
-        Log a message with the given logger at the given level or simply print.
+        Given KeyValueLists, convert to dictionaries and remove any keys found in the
+        second (subtrahend) from the first (minuend), if present.
+
+        :param minuend: list to be subtracted from
+        :param subtrahend: list whose keys will be removed from the minuend
+
+        :returns: the difference of the two lists
         """
-        if logger:
-            logger.log(level, msg)
-        else:
-            print(msg)
+        subtract_dict = minuend.to_dict()
+        for key in subtrahend.to_dict().keys():
+            if key in subtract_dict:
+                subtract_dict.pop(key)
+
+        return KeyValueList.from_dict(subtract_dict)
+
+
+@dataclass
+class VolumeMount:
+    path: str
+    pvc_name: str
+
+
+@dataclass
+class KubernetesSecret:
+    env_var: str
+    name: str
+    key: str
+
+
+@dataclass
+class KubernetesToleration:
+    key: str
+    operator: str
+    value: str
+    effect: str
+
+
+@dataclass
+class KubernetesAnnotation:
+    key: str
+    value: str
+
+
+class DataClassJSONEncoder(json.JSONEncoder):
+    """
+    A JSON Encoder class to prevent errors during serialization of dataclasses.
+    """
+
+    def default(self, o):
+        """
+        Render dataclass content as dict
+        """
+        if is_dataclass(o):
+            return dataclass_asdict(o)
+        return super().default(o)
